Demo page

Description

## Demo

# Calendar

- #### Read the patterns calendar documentation

  - Starts 5 January 2013, 9:00 (UTC+2)
  - Ends 8 January 2013, 17:00 (UTC+2)

- #### Patterns sprint

  Munich

  - Starts 11 January 2013
  - Ends 15 January 2013

- #### Prototype review

  - Starts 4 September 2013, 10:00 (UTC+2)
  - Ends 4 September 2013, 16:30 (UTC+2)

- #### Report Deadline: Focus on Baggage

  The new Report on "Focus on Baggage" goes out today.

  - Starts 5 September 2013
  - Ends 5 September 2013
  - Location Star HQ, Germany

- #### Annual Baggage Handling Workgroup Meeting

  Star Alliance is proud to offer its 10th annual Baggage Handling Workgroup Program in September 2013. This program provides you an introduction to the forecasting and optimization models found in baggage handling systems and focuses on recent research and new developments in baggage handling models for changing and less restricted baggage environments.

  - Starts 10 September 2013
  - Ends 12 September 2013
  - Location Frankfurt, Germany
  - Status

- #### Report Deadline: Key Flight Report

  Key Flight Report Deadline

  - Starts 15 September 2013
  - Ends 15 September 2013

- #### Face-to-Face Meeting (CPT)

  Objective: To review current connection baggage performance overall and at the airports. Review current performance. Demonstration of the new baggage application and its potential to reduce delays.

  - Starts 18 September 2013
  - Ends 19 September 2013
  - Location Cape Town, South Africa
  - Status

- #### Baffling Baggage Ball (CPT)

  To celebrate another successful year with even less lost luggage!

  - Starts 20 September 2013, 18:00 (UTC+2)
  - Ends 21 September 2013, 04:00 (UTC+2)
  - Location Cape Town Crystal Tower, South Africa
  - Status

- #### FoB Savings update

  Publication of the new "Mishandled Bag Files Created" Statistics

  - Starts 30 September 2013, 12:00 (UTC+2)
  - Ends 30 September 2013, 12:00 (UTC+2)
  - Location Frankfurt, Germany

- #### Safety Stratey Team Meeting (Singapore)

  - Starts 9 January 2014, 09:00 (UTC+2)
  - Ends 9 January 2014, 17:00 (UTC+2)

- #### Emergency Strategy Team Meeting (Singapore)

  - Starts 12 January 2014, 09:00 (UTC+2)
  - Ends 12 January 2014, 17:00 (UTC+2)

- #### Marketing Strategy Team Meeting (Radisson Blu Edwardian, Heathrow)

  - Starts 10 February 2014
  - Ends 14 February 2014

- #### Customer Experience Strategy Team Meeting (Radisson Blu Edwardian, Heathrow)

  - Starts 10 September 2013
  - Ends 11 September 2013

- #### IT Strategy Team Meeting (Radisson Blu Edwardian, Heathrow)

  - Starts 11 September 2013
  - Ends 12 September 2013

- #### Loyalty Strategy Team Meeting (Radisson Blu Edwardian, Heathrow)

  - Starts 11 September 2013, 09:00 (UTC+2)
  - Ends 12 September 2013, 12:30 (UTC+2)

- #### Commercial Cooperation Strategy Team Meeting (Radisson Blu Edwardian, Heathrow)

  - Starts 12 September 2013
  - Ends 13 September 2013

- #### Membership Liaison and Quality Committee Meeting (Frankfurt)

  - Starts 17 September 2013
  - Ends 18 September 2013

- #### SAAT Meeting (South Mezzanine Conf)

  - Starts 18 September 2013, 10:00 (UTC+2)
  - Ends 18 September 2013, 11:00 (UTC+2)

- #### STAR BE CSMG/CSC MEETING (BRU)

  - Starts 19 September 2013, 10:00 (UTC+2)
  - Ends 19 September 2013, 15:00 (UTC+2)

- #### Revenue Management Education Program 2013 (Bangkok)

  - Starts 23 September 2013
  - Ends 27 September 2013

- #### STAR NL CSMG MEETING (AMS)

  - Starts 24 September 2013
  - Ends 26 September 2013

- #### STAR NL CSC MEETING (AMS)

  - Starts 26 September 2013, 10:00 (UTC+2)
  - Ends 26 September 2013, 12:00 (UTC+2)

- #### IT Committee Meeting - LHR (LHR)

  - Starts 8 October 2013
  - Ends 9 October 2013

- #### Marketing Committee (LHR)

  - Starts 8 October 2013, 09:00 (UTC+2)
  - Ends 8 October 2013, 18:00 (UTC+2)

- #### STAR BE CSMG MEETING (BRU)

  - Starts 8 October 2013, 10:00 (UTC+2)
  - Ends 8 October 2013, 12:00 (UTC+2)

- #### Customer Experience Committee Meeting - LHR (LHR)

  - Starts 9 October 2013
  - Ends 10 October 2013

- #### Commercial Cooperation (LHR)

  - Starts 10 October 2013, 09:00 (UTC+2)
  - Ends 10 October 2013, 18:00 (UTC+2)

- #### Loyalty Committee Meeting (LHR)

  - Starts 9 October 2013, 09:00 (UTC+2)
  - Ends 9 October 2013, 18:00 (UTC+2)

- #### Release of the 2013 Network Facts & Figures

  - Starts 26 September 2013, 12:00 (UTC+2)

- #### Performance Report Data Collection Meeting

  - Starts 20 September 2013, 10:00 (UTC+2)
  - Ends 20 September 2013, 11:30 (UTC+2)

- #### Update: SAUA Product Feature Matrix All Carriers SEP13

  - Starts 13 September 2013, 14:00 (UTC+2)
  - Ends 20 September 2013, 14:00 (UTC+2)

- #### SCP ERCMTE Meeting

  - Starts 16 September 2013
  - Ends 18 September 2013

- #### AMB 16-17 November 2011, Frankfurt

  Alliance Management Board Meeting 16-17 November 2013

  - Starts 16 November 2013 (UTC+2)
  - Ends 17 November 2013 (UTC+2)
  - Location Frankfurt, Germany

- #### Prolonged weekend of german unity (LH)

  - Starts 6 September 2013
  - Ends 9 September 2013

- #### Labour Day (JP, A3, AC, CA, NZ, NH, OZ, OS, AV, SN, CM, OU, MS, ET, BR, LO, LH, SK, ZH, SQ, SA, LX, JJ, TP, TG, TK, UA, US)

  - Starts 19 September 2013
  - Ends 19 September 2013

Documentation